==> HROOT-hist-0.8.tar.gz: HROOT-hist-0.8/csrc/HROOT-histType.h <==
#ifdef __cplusplus
extern "C" { 
#endif

#ifndef __HROOT_HIST__
#define __HROOT_HIST__

// Opaque type definition for TAxis 
typedef struct TAxis_tag TAxis_t; 
typedef TAxis_t * TAxis_p; 
typedef TAxis_t const* const_TAxis_p; 

// Opaque type definition for TF1 
typedef struct TF1_tag TF1_t; 
typedef TF1_t * TF1_p; 
typedef TF1_t const* const_TF1_p; 

// Opaque type definition for TFormula 
typedef struct TFormula_tag TFormula_t; 
typedef TFormula_t * TFormula_p; 
typedef TFormula_t const* const_TFormula_p; 

// Opaque type definition for TGraph 
typedef struct TGraph_tag TGraph_t; 
typedef TGraph_t * TGraph_p; 
typedef TGraph_t const* const_TGraph_p; 

// Opaque type definition for TGraphAsymmErrors 
typedef struct TGraphAsymmErrors_tag TGraphAsymmErrors_t; 
typedef TGraphAsymmErrors_t * TGraphAsymmErrors_p; 
typedef TGraphAsymmErrors_t const* const_TGraphAsymmErrors_p; 

// Opaque type definition for TGraphBentErrors 
typedef struct TGraphBentErrors_tag TGraphBentErrors_t; 
typedef TGraphBentErrors_t * TGraphBentErrors_p; 
typedef TGraphBentErrors_t const* const_TGraphBentErrors_p; 

// Opaque type definition for TGraphErrors 
typedef struct TGraphErrors_tag TGraphErrors_t; 
typedef TGraphErrors_t * TGraphErrors_p; 
typedef TGraphErrors_t const* const_TGraphErrors_p; 

// Opaque type definition for TH1 
typedef struct TH1_tag TH1_t; 
typedef TH1_t * TH1_p; 
typedef TH1_t const* const_TH1_p; 

// Opaque type definition for TH1C 
typedef struct TH1C_tag TH1C_t; 
typedef TH1C_t * TH1C_p; 
typedef TH1C_t const* const_TH1C_p; 

// Opaque type definition for TH1D 
typedef struct TH1D_tag TH1D_t; 
typedef TH1D_t * TH1D_p; 
typedef TH1D_t const* const_TH1D_p; 

// Opaque type definition for TH1F 
typedef struct TH1F_tag TH1F_t; 
typedef TH1F_t * TH1F_p; 
typedef TH1F_t const* const_TH1F_p; 

// Opaque type definition for TH1I 
typedef struct TH1I_tag TH1I_t; 
typedef TH1I_t * TH1I_p; 
typedef TH1I_t const* const_TH1I_p; 

// Opaque type definition for TH1K 
typedef struct TH1K_tag TH1K_t; 
typedef TH1K_t * TH1K_p; 
typedef TH1K_t const* const_TH1K_p; 

// Opaque type definition for TH1S 
typedef struct TH1S_tag TH1S_t; 
typedef TH1S_t * TH1S_p; 
typedef TH1S_t const* const_TH1S_p; 

// Opaque type definition for TH2 
typedef struct TH2_tag TH2_t; 
typedef TH2_t * TH2_p; 
typedef TH2_t const* const_TH2_p; 

// Opaque type definition for TH2C 
typedef struct TH2C_tag TH2C_t; 
typedef TH2C_t * TH2C_p; 
typedef TH2C_t const* const_TH2C_p; 

// Opaque type definition for TH2D 
typedef struct TH2D_tag TH2D_t; 
typedef TH2D_t * TH2D_p; 
typedef TH2D_t const* const_TH2D_p; 

// Opaque type definition for TH2F 
typedef struct TH2F_tag TH2F_t; 
typedef TH2F_t * TH2F_p; 
typedef TH2F_t const* const_TH2F_p; 

// Opaque type definition for TH2I 
typedef struct TH2I_tag TH2I_t; 
typedef TH2I_t * TH2I_p; 
typedef TH2I_t const* const_TH2I_p; 

// Opaque type definition for TH2Poly 
typedef struct TH2Poly_tag TH2Poly_t; 
typedef TH2Poly_t * TH2Poly_p; 
typedef TH2Poly_t const* const_TH2Poly_p; 

// Opaque type definition for TH2S 
typedef struct TH2S_tag TH2S_t; 
typedef TH2S_t * TH2S_p; 
typedef TH2S_t const* const_TH2S_p; 

// Opaque type definition for TH3 
typedef struct TH3_tag TH3_t; 
typedef TH3_t * TH3_p; 
typedef TH3_t const* const_TH3_p; 

// Opaque type definition for TH3C 
typedef struct TH3C_tag TH3C_t; 
typedef TH3C_t * TH3C_p; 
typedef TH3C_t const* const_TH3C_p; 

// Opaque type definition for TH3D 
typedef struct TH3D_tag TH3D_t; 
typedef TH3D_t * TH3D_p; 
typedef TH3D_t const* const_TH3D_p; 

// Opaque type definition for TH3F 
typedef struct TH3F_tag TH3F_t; 
typedef TH3F_t * TH3F_p; 
typedef TH3F_t const* const_TH3F_p; 

// Opaque type definition for TH3I 
typedef struct TH3I_tag TH3I_t; 
typedef TH3I_t * TH3I_p; 
typedef TH3I_t const* const_TH3I_p; 

// Opaque type definition for TH3S 
typedef struct TH3S_tag TH3S_t; 
typedef TH3S_t * TH3S_p; 
typedef TH3S_t const* const_TH3S_p; 

// Opaque type definition for THStack 
typedef struct THStack_tag THStack_t; 
typedef THStack_t * THStack_p; 
typedef THStack_t const* const_THStack_p; 

#endif // __HROOT_HIST__

#ifdef __cplusplus
}
#endif

==> HROOT-hist-0.9.tar.gz: HROOT-hist-0.9/csrc/HROOT-histType.h <==
#ifdef __cplusplus
extern "C" { 
#endif

#ifndef __HROOT_HIST__
#define __HROOT_HIST__

// Opaque type definition for TAxis 
typedef struct TAxis_tag TAxis_t; 
typedef TAxis_t * TAxis_p; 
typedef TAxis_t const* const_TAxis_p; 


// Opaque type definition for TF1 
typedef struct TF1_tag TF1_t; 
typedef TF1_t * TF1_p; 
typedef TF1_t const* const_TF1_p; 


// Opaque type definition for TFitResult 
typedef struct TFitResult_tag TFitResult_t; 
typedef TFitResult_t * TFitResult_p; 
typedef TFitResult_t const* const_TFitResult_p; 


// Opaque type definition for TFitResultPtr 
typedef struct TFitResultPtr_tag TFitResultPtr_t; 
typedef TFitResultPtr_t * TFitResultPtr_p; 
typedef TFitResultPtr_t const* const_TFitResultPtr_p; 


// Opaque type definition for TGraph 
typedef struct TGraph_tag TGraph_t; 
typedef TGraph_t * TGraph_p; 
typedef TGraph_t const* const_TGraph_p; 


// Opaque type definition for TGraphAsymmErrors 
typedef struct TGraphAsymmErrors_tag TGraphAsymmErrors_t; 
typedef TGraphAsymmErrors_t * TGraphAsymmErrors_p; 
typedef TGraphAsymmErrors_t const* const_TGraphAsymmErrors_p; 


// Opaque type definition for TGraphBentErrors 
typedef struct TGraphBentErrors_tag TGraphBentErrors_t; 
typedef TGraphBentErrors_t * TGraphBentErrors_p; 
typedef TGraphBentErrors_t const* const_TGraphBentErrors_p; 


// Opaque type definition for TGraphErrors 
typedef struct TGraphErrors_tag TGraphErrors_t; 
typedef TGraphErrors_t * TGraphErrors_p; 
typedef TGraphErrors_t const* const_TGraphErrors_p; 


// Opaque type definition for TH1 
typedef struct TH1_tag TH1_t; 
typedef TH1_t * TH1_p; 
typedef TH1_t const* const_TH1_p; 


// Opaque type definition for TH1C 
typedef struct TH1C_tag TH1C_t; 
typedef TH1C_t * TH1C_p; 
typedef TH1C_t const* const_TH1C_p; 


// Opaque type definition for TH1D 
typedef struct TH1D_tag TH1D_t; 
typedef TH1D_t * TH1D_p; 
typedef TH1D_t const* const_TH1D_p; 


// Opaque type definition for TH1F 
typedef struct TH1F_tag TH1F_t; 
typedef TH1F_t * TH1F_p; 
typedef TH1F_t const* const_TH1F_p; 


// Opaque type definition for TH1I 
typedef struct TH1I_tag TH1I_t; 
typedef TH1I_t * TH1I_p; 
typedef TH1I_t const* const_TH1I_p; 


// Opaque type definition for TH1K 
typedef struct TH1K_tag TH1K_t; 
typedef TH1K_t * TH1K_p; 
typedef TH1K_t const* const_TH1K_p; 


// Opaque type definition for TH1S 
typedef struct TH1S_tag TH1S_t; 
typedef TH1S_t * TH1S_p; 
typedef TH1S_t const* const_TH1S_p; 


// Opaque type definition for TH2 
typedef struct TH2_tag TH2_t; 
typedef TH2_t * TH2_p; 
typedef TH2_t const* const_TH2_p; 


// Opaque type definition for TH2C 
typedef struct TH2C_tag TH2C_t; 
typedef TH2C_t * TH2C_p; 
typedef TH2C_t const* const_TH2C_p; 


// Opaque type definition for TH2D 
typedef struct TH2D_tag TH2D_t; 
typedef TH2D_t * TH2D_p; 
typedef TH2D_t const* const_TH2D_p; 


// Opaque type definition for TH2F 
typedef struct TH2F_tag TH2F_t; 
typedef TH2F_t * TH2F_p; 
typedef TH2F_t const* const_TH2F_p; 


// Opaque type definition for TH2I 
typedef struct TH2I_tag TH2I_t; 
typedef TH2I_t * TH2I_p; 
typedef TH2I_t const* const_TH2I_p; 


// Opaque type definition for TH2Poly 
typedef struct TH2Poly_tag TH2Poly_t; 
typedef TH2Poly_t * TH2Poly_p; 
typedef TH2Poly_t const* const_TH2Poly_p; 


// Opaque type definition for TH2S 
typedef struct TH2S_tag TH2S_t; 
typedef TH2S_t * TH2S_p; 
typedef TH2S_t const* const_TH2S_p; 


// Opaque type definition for TH3 
typedef struct TH3_tag TH3_t; 
typedef TH3_t * TH3_p; 
typedef TH3_t const* const_TH3_p; 


// Opaque type definition for TH3C 
typedef struct TH3C_tag TH3C_t; 
typedef TH3C_t * TH3C_p; 
typedef TH3C_t const* const_TH3C_p; 


// Opaque type definition for TH3D 
typedef struct TH3D_tag TH3D_t; 
typedef TH3D_t * TH3D_p; 
typedef TH3D_t const* const_TH3D_p; 


// Opaque type definition for TH3F 
typedef struct TH3F_tag TH3F_t; 
typedef TH3F_t * TH3F_p; 
typedef TH3F_t const* const_TH3F_p; 


// Opaque type definition for TH3I 
typedef struct TH3I_tag TH3I_t; 
typedef TH3I_t * TH3I_p; 
typedef TH3I_t const* const_TH3I_p; 


// Opaque type definition for TH3S 
typedef struct TH3S_tag TH3S_t; 
typedef TH3S_t * TH3S_p; 
typedef TH3S_t const* const_TH3S_p; 


// Opaque type definition for THStack 
typedef struct THStack_tag THStack_t; 
typedef THStack_t * THStack_p; 
typedef THStack_t const* const_THStack_p; 


#endif // __HROOT_HIST__

#ifdef __cplusplus
}
#endif
